@@ -2,7 +2,7 @@
 /**
  * Horde_Cli API for basic command-line functionality/checks.
  *
- * Copyright 2003-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -472,7 +472,7 @@ class Horde_Cli
      *
      * @return Horde_Cli  A Horde_Cli instance.
      */
-    static public function init()
+    public static function init()
     {
         /* Run constructor now because it requires $_SERVER['SERVER_NAME'] to
          * be empty if called with a CGI SAPI. */
@@ -514,7 +514,7 @@ class Horde_Cli
      *
      * @return boolean  True if we are, false otherwise.
      */
-    static public function runningFromCLI()
+    public static function runningFromCLI()
     {
         return (PHP_SAPI == 'cli') ||
                (((PHP_SAPI == 'cgi') || (PHP_SAPI == 'cgi-fcgi')) &&
